@@ -1,13 +1,10 @@
-__version__ = "0.3.2"
+__version__ = "0.3.5"
 WORDNET = "wordnet"
 POINCARE = "poincare"
 
 def load(vectors:str=WORDNET):
     if vectors==WORDNET:
         from ffast.wordnet.tokeniser import Tokeniser
-        from nltk import download
-        download(WORDNET)
-        download('stopwords')
         return Tokeniser()
     if vectors==POINCARE:
         from ffast.poincare.tokeniser import Tokeniser
