@@ -17,4 +17,8 @@ class Poincare(Enum):
     SIZE_VECTOR = 100
     SIZE_VOCABULARY = len(VOCABULARY)
     UNKNOWN = "<Unknown>"
-    SKIP = "skip"
\ No newline at end of file
+    SKIP = "skip"
+
+SIZE_TOKEN_VECTOR = Poincare.SIZE_VECTOR.value + SIZE_METAPHONES
+SIZE_POWER_MEANS_VECTOR = 5*SIZE_TOKEN_VECTOR
+SIZE_SENTENCE_VECTOR = 2*SIZE_POWER_MEANS_VECTOR
\ No newline at end of file
